pub struct Move {
pub kind: MoveKind,
pub a_idx: Option<usize>,
pub b_idx: Option<usize>,
pub cost: f64,
pub confidence: f64,
}Expand description
One move in the alignment. The invariant tying kind to the indices — sync has both, log
has only b_idx, model has only a_idx — is guaranteed by the Move::sync/Move::log
/Move::model constructors.
Fields
kind: MoveKinda_idx: Option<usize>Step index in run a, present unless this is a log-only move.
b_idx: Option<usize>Step index in run b, present unless this is a model-only move.
cost: f64Alignment cost of this move (lower = more similar). Domain of the cost model.
confidence: f64Confidence in this move, in [0, 1].
Implementations
Sourceimpl Move
impl Move